Module: Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::HarmCategory
- Defined in:
- proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb
Overview
Harm categories that will block the content.
Constant Summary collapse
- HARM_CATEGORY_UNSPECIFIED =
Default value. This value is unused.
0- HARM_CATEGORY_HATE_SPEECH =
Content that promotes violence or incites hatred against individuals or groups based on certain attributes.
1- HARM_CATEGORY_DANGEROUS_CONTENT =
Content that promotes, facilitates, or enables dangerous activities.
2- HARM_CATEGORY_HARASSMENT =
Abusive, threatening, or content intended to bully, torment, or ridicule.
3- HARM_CATEGORY_SEXUALLY_EXPLICIT =
Content that contains sexually explicit material.
4