Class: Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::SafetySetting
- Inherits:
-
Object
- Object
- Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::SafetySetting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb
Overview
Safety setting for a single harm category.
Instance Attribute Summary collapse
-
#category ⇒ ::Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::HarmCategory
The harm category to apply the safety setting to.
-
#threshold ⇒ ::Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::HarmBlockThreshold
The harm block threshold for the safety setting.
Instance Attribute Details
#category ⇒ ::Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::HarmCategory
Returns The harm category to apply the safety setting to.
100 101 102 103 |
# File 'proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb', line 100 class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#threshold ⇒ ::Google::Cloud::TextToSpeech::V1beta1::AdvancedVoiceOptions::HarmBlockThreshold
Returns The harm block threshold for the safety setting.
100 101 102 103 |
# File 'proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb', line 100 class SafetySetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |