Class: Google::Cloud::TextToSpeech::V1beta1::CustomPronunciationParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb

Overview

Pronunciation customization for a phrase.

Defined Under Namespace

Modules: PhoneticEncoding

Instance Attribute Summary collapse

Instance Attribute Details

#phonetic_encoding::Google::Cloud::TextToSpeech::V1beta1::CustomPronunciationParams::PhoneticEncoding

Returns The phonetic encoding of the phrase.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb', line 198

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2

    # For reading-to-pron conversion to work well, the `pronunciation` field
    #  should only contain Kanji, Hiragana, and Katakana.
    #
    # The pronunciation can also contain pitch accents.
    # The start of a pitch phrase is specified with `^` and the down-pitch
    # position is specified with `!`, for example:
    #
    #     phrase:端  pronunciation:^はし
    #     phrase:箸  pronunciation:^は!し
    #     phrase:橋  pronunciation:^はし!
    #
    # We currently only support the Tokyo dialect, which allows at most one
    # down-pitch per phrase (i.e. at most one `!` between `^`).
    PHONETIC_ENCODING_JAPANESE_YOMIGANA = 3

    # Used to specify pronunciations for Mandarin words. See
    # https://en.wikipedia.org/wiki/Pinyin.
    #
    # For example: 朝阳, the pronunciation is "chao2 yang2". The number
    # represents the tone, and there is a space between syllables. Neutral
    # tones are represented by 5, for example 孩子 "hai2 zi5".
    PHONETIC_ENCODING_PINYIN = 4
  end
end

#phrase::String

Returns The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn't span the length of the sentence.

Returns:

  • (::String)

    The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn't span the length of the sentence.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb', line 198

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2

    # For reading-to-pron conversion to work well, the `pronunciation` field
    #  should only contain Kanji, Hiragana, and Katakana.
    #
    # The pronunciation can also contain pitch accents.
    # The start of a pitch phrase is specified with `^` and the down-pitch
    # position is specified with `!`, for example:
    #
    #     phrase:端  pronunciation:^はし
    #     phrase:箸  pronunciation:^は!し
    #     phrase:橋  pronunciation:^はし!
    #
    # We currently only support the Tokyo dialect, which allows at most one
    # down-pitch per phrase (i.e. at most one `!` between `^`).
    PHONETIC_ENCODING_JAPANESE_YOMIGANA = 3

    # Used to specify pronunciations for Mandarin words. See
    # https://en.wikipedia.org/wiki/Pinyin.
    #
    # For example: 朝阳, the pronunciation is "chao2 yang2". The number
    # represents the tone, and there is a space between syllables. Neutral
    # tones are represented by 5, for example 孩子 "hai2 zi5".
    PHONETIC_ENCODING_PINYIN = 4
  end
end

#pronunciation::String

Returns The pronunciation of the phrase. This must be in the phonetic encoding specified above.

Returns:

  • (::String)

    The pronunciation of the phrase. This must be in the phonetic encoding specified above.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'proto_docs/google/cloud/texttospeech/v1beta1/cloud_tts.rb', line 198

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2

    # For reading-to-pron conversion to work well, the `pronunciation` field
    #  should only contain Kanji, Hiragana, and Katakana.
    #
    # The pronunciation can also contain pitch accents.
    # The start of a pitch phrase is specified with `^` and the down-pitch
    # position is specified with `!`, for example:
    #
    #     phrase:端  pronunciation:^はし
    #     phrase:箸  pronunciation:^は!し
    #     phrase:橋  pronunciation:^はし!
    #
    # We currently only support the Tokyo dialect, which allows at most one
    # down-pitch per phrase (i.e. at most one `!` between `^`).
    PHONETIC_ENCODING_JAPANESE_YOMIGANA = 3

    # Used to specify pronunciations for Mandarin words. See
    # https://en.wikipedia.org/wiki/Pinyin.
    #
    # For example: 朝阳, the pronunciation is "chao2 yang2". The number
    # represents the tone, and there is a space between syllables. Neutral
    # tones are represented by 5, for example 孩子 "hai2 zi5".
    PHONETIC_ENCODING_PINYIN = 4
  end
end